<?
/////////////////////////////////////////////////////////////////////////////////
// Photo Gallery (writer: Eli Hen)                                             //
// -------------                                                               //
//                                                                             //
// File Name: gallery.php                                                      //
// Additional Files:                                                           //
//   * gallery_conf.inc - configuration file (variables setup).                //
//   * show_picture.php - shows the clicked picture.                           //
//                                                                             //
//                                                                             //
// What Does It Do?                                                            //
//   This script displays a photo gallery in the browser. The script in not    //
//   based on a MySQL DB, but on a data file contains data about the original  //
//   photos, their thumbnails, title and description. There's no limit on the  //
//   number of photos. In the gallery we display the thumbnail (to make it load//
//   faster, and when you click on a picture, a window is opened and shows the //
//   original photo, with it's description. You can set the number of photos to//
//   show in row/column, and the gallery will have 'next'-'prev' buttons.      //
//                                                                             //
// How It Works?                                                               //
//   The script reads a gallery data file, and gets from it the locations of   //
//   the thumbnail and the original photo, the title of the photo and its      //
//   description. Then, we loop over the entries we read from the file, and    //
//   display the photos thumbnails. we show in each page only the number of    //
//   photos that was set per page.                                             //
//                                                                             //
// MySQL DB: NONE                                                              //
//                                                                             //
// Data Files:                                                                 //
//    * Gallery Data File: (user's file name)                                  //
//       - The sign '$' seperates between the photos in the file.              //
//       - The sign '|' seperates between the photo info (location, thumbnail, //
//         title and description).                                             //
//       - (the script skips on empty rows.)                                   //
//       - (the photos location paths should be relative to the data file.)    //
//                                                                             //
// Installation:                                                               //
//   To set up the photo gallery you have to create thumbnails to your photos  //
//   so it will load faster. if you don't have thumbnails, set the thumbnails  //
//   location in the data file to the original photo- That would be slower.    //
//   Create the gallery data file: seperate the photos by $ and the photo info //
//   fields by |. You have to specify the original and thumbnails locations to //
//   see the photos, the title and the description are optional. Set the setup //
//   variables to the correct values:                                          //
//     - $gallery_file = the location of the gallery data file.                //
//     - $gallery_name = the title of the gallery.                             //
//     - $gallery_pics_per_page_width = max number of photos in width per page.//
//     - $gallery_pics_per_page_height = max number of photos in height per    //
//       page.                                                                 //
//     - $gallery_thumb_width = the exact width you want to display the        //
//       thumbnails (the height will change according to the thumbnail actual  //
//       size).                                                                //
//     - $gallery_default_pic_name = the default photo name when the photo     //
//       title is not set in the data file.                                    //
//                                                                             //
//                              ENJOY!!!                                       //
/////////////////////////////////////////////////////////////////////////////////


require "gallery_conf.inc";  //exports the configuration file

/* Returns an array of the photos names and locations of a gallery file. */
function GetPhotos($file)
{
	global $gallery_default_pic_name;  //the default picture name (global)

	$fp=@fopen($file,"r");  //trying to read the file
   if (!$fp)  //if couldn't read the file
   	return FALSE;
	$fl=@fread($fp,filesize($file));  //reads the entire file to $fl
	$p=explode("\$",$fl);  //explodes the contents of the file to pictures data array ($p)
   $pic=NULL;  //variable to store all the data
   for ($i=1;$i<count($p);$i++)  //goes over all the pictures data
   {
   	str_replace("\$","",$p[$i]);  //removes the $ sign
      list($pic_file,$pic_thumb,$pic_name,$pic_desc)=explode("|",$p[$i],4);  //explodes the picture data into 4 pieces: file, thumbnail, name and description.
		if (!$pic_name)  //if empty name
      	$pic_name=$gallery_default_pic_name;  //sets default name
		$pic[]=array('pic_file'=>trim($pic_file),'pic_thumb'=>trim($pic_thumb),'pic_name'=>trim($pic_name),'pic_desc'=>trim($pic_desc));  //adds the picture info to the pictures array we'll return later (trim() removes white spaces)
   }
   @fclose($fp);  //closing the file
   return $pic;  //returns the array of the pictures in the gallery
}
?>

<HTML>
<HEAD>
<META http-equiv="content-type" content="text/HTML; charset=windows-1255">
<META http-equiv="content-language" content="hw">
	<TITLE> </TITLE>
</HEAD>

<SCRIPT language="JavaScript">
<!--
	function GalleryOpenPicture(pic,name,desc,width,height)
   {
   	window.open("show_picture.php?pic="+pic+"&name="+name+"&desc="+desc,null,"width="+(width+50)+" height="+(height+100)+" toolbar=no location=no directories=no status=no menubar=no resizable=yes scrollbars=yes top=0 left=0",true);
   }
-->
</SCRIPT>

<BODY>
<DIV align="center" dir="rtl">
<H1><FONT color="#3399FF"><U><?= $gallery_name; ?></U></FONT></H1>

<?
if (!isset($gallerypage))  //if the page is not specified
  	$gallerypage=1;  //we set it to the first page

$gallery_pics=GetPhotos($gallery_file);  //$pics has the pictures data
if (!$gallery_pics)  //if cannot load the gallery
{
	echo "<B>:</B>     .<BR>\n";  //printing error message
   exit;  //exit the program
}

	$gallery_dir=dirname($gallery_file)."/";  //$dir is the directory path to the gallery
	$gallery_cur=($gallerypage-1)*$gallery_pics_per_page_height*$gallery_pics_per_page_width;  //the current number of picture
   echo "<TABLE border=1 bgcolor=\"#000000\" cellpadding=3 cellspacing=5>\n";  //starting the table
	for ($gallery_i=0;$gallery_i<$gallery_pics_per_page_height;$gallery_i++)  //goes over the rows
   {
   	echo "<TR align=\"center\" valign=\"top\">\n";  //starting a new line
   	for ($gallery_j=0;$gallery_j<$gallery_pics_per_page_width;$gallery_j++)  //goes over the columns
      {
         if (isset($gallery_pics[$gallery_cur]))  //if the entry is set, we print the image thumnail in the table
         {
         	$gallery_img_size=@getimagesize($gallery_dir.$gallery_pics[$gallery_cur]['pic_file']);
   	   	echo "<TD>\n";
	         echo "<A href=\"javascript:GalleryOpenPicture('".$gallery_dir.$gallery_pics[$gallery_cur]['pic_file']."','".($gallery_pics[$gallery_cur]['pic_name'])."','".(nl2br($gallery_pics[$gallery_cur]['pic_desc']))."',".$gallery_img_size[0].",".$gallery_img_size[1].")\"><IMG src=\"".$gallery_dir.$gallery_pics[$gallery_cur]['pic_thumb']."\" alt=\"".$gallery_pics[$gallery_cur]['pic_name']."\"";
            echo ($gallery_thumb_width>0)?" width=".$gallery_thumb_width:"";
            echo ($gallery_thumb_height>0)?" height=".$gallery_thumb_height:"";
            echo " border=0><BR><FONT color=\"#44BB99\">".wordwrap($gallery_pics[$gallery_cur]['pic_name'],13,"<BR>")."</FONT></A>\n";  //prints the image and its link
      	   echo "</TD>\n";
         }
         else  //else if there's no entry, we end the table
         {
         	echo "</TR>\n";  //ends the line
         	break 2;  //stopping the 2 loops
         }
         $gallery_cur++;  //going to the next picture
      }
      echo "</TR>";  //closing the line
   }

   //prints the 'next'-'prev' links:
   echo "<TR>\n<TD colspan=$gallery_pics_per_page_width><TABLE  bgcolor=\"#99CCCC\" width=100% border=0 cellpadding=2 cellspacing=0>\n<TR>\n<TD width=50% align=\"right\">";
   if ($gallerypage>1)
   	echo "<A href=\"$PHP_SELF?gallerypage=".($gallerypage-1)."\"></A>";
   echo "</TD>\n<TD width=50% align=\"left\">";
 	if ($gallery_cur<count($gallery_pics))
   	echo "<A href=\"$PHP_SELF?gallerypage=".($gallerypage+1)."\"></A>";
   echo "</TD>\n</TR>\n</TABLE>\n</TR>\n</TABLE>\n";
?>

</BODY>
</DIV>
</HTML>